@@ -2,23 +2,25 @@ use std::env;
 use std::ffi::OsString;
 use std::path::PathBuf;
 
-use anyhow::{Context, Result};
+use anyhow::{Context, Result, ensure};
 use glob::Pattern;
 
 use crate::db::Rank;
 
 pub fn data_dir() -> Result<PathBuf> {
-    let path = match env::var_os("_ZO_DATA_DIR") {
+    let dir = match env::var_os("_ZO_DATA_DIR") {
         Some(path) => PathBuf::from(path),
         None => dirs::data_local_dir()
             .context("could not find data directory, please set _ZO_DATA_DIR manually")?
             .join("zoxide"),
     };
-    Ok(path)
+
+    ensure!(dir.is_absolute(), "_ZO_DATA_DIR must be an absolute path");
+    Ok(dir)
 }
 
 pub fn echo() -> bool {
-    env::var_os("_ZO_ECHO").map_or(false, |var| var == "1")
+    env::var_os("_ZO_ECHO").is_some_and(|var| var == "1")
 }
 
 pub fn exclude_dirs() -> Result<Vec<Pattern>> {
@@ -56,5 +58,5 @@ pub fn maxage() -> Result<Rank> {
 }
 
 pub fn resolve_symlinks() -> bool {
-    env::var_os("_ZO_RESOLVE_SYMLINKS").map_or(false, |var| var == "1")
+    env::var_os("_ZO_RESOLVE_SYMLINKS").is_some_and(|var| var == "1")
 }
