@@ -18,8 +18,8 @@ use crate::error::SilentExit;
 
 pub fn main() -> ExitCode {
     // Forcibly disable backtraces.
-    env::remove_var("RUST_LIB_BACKTRACE");
-    env::remove_var("RUST_BACKTRACE");
+    unsafe { env::remove_var("RUST_LIB_BACKTRACE") };
+    unsafe { env::remove_var("RUST_BACKTRACE") };
 
     match Cmd::parse().run() {
         Ok(()) => ExitCode::SUCCESS,
